==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/streambrowser/translations/streambrowser_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translation>Обзор потоков</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="28"/>
        <source>Stream Browser Plugin</source>
        <translation>Модуль обзора потоков</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="49"/>
        <source>About Stream Browser Plugin</source>
        <translation>О модуле обзора потоков</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Модуль обзора потоков для Qmmp</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>This plugin allows to add stream from IceCast stream directory</source>
        <translation>Этот модуль предназначен для добавления потоков из директории IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Обзор потоков</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="51"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="125"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Добавить в избранное</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to playlist</source>
        <translation>&amp;Добавить в список воспроизведения</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="131"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="141"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="144"/>
        <location filename="../streamwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Получение</translation>
    </message>
</context>
</TS>

==> qmmp-0.8.5.tar.bz2: qmmp-0.8.5/src/plugins/General/streambrowser/translations/streambrowser_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translation>Обзор потоков</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="28"/>
        <source>Stream Browser Plugin</source>
        <translation>Модуль обзора потоков</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="49"/>
        <source>About Stream Browser Plugin</source>
        <translation>О модуле обзора потоков</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Модуль обзора потоков для Qmmp</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Этот модуль предназначен для добавления потоков из директории IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Обзор потоков</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="51"/>
        <location filename="../streamwindow.cpp" line="69"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="125"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Добавить в избранное</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to playlist</source>
        <translation>&amp;Добавить в список воспроизведения</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="131"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="141"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="144"/>
        <location filename="../streamwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Получение</translation>
    </message>
</context>
</TS>
